pub struct ListDataCatalogsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListDataCatalogs.
Lists the data catalogs in the current Amazon Web Services account.
In the Athena console, data catalogs are listed as "data sources" on the Data sources page under the Data source name column.
Implementations
Sourceimpl ListDataCatalogsFluentBuilder
impl ListDataCatalogsFluentBuilder
Sourcepub fn as_input(&self) -> &ListDataCatalogsInputBuilder
pub fn as_input(&self) -> &ListDataCatalogsInputBuilder
Access the ListDataCatalogs as a reference.
Sourcepub async fn send(
self,
) -> Result<ListDataCatalogsOutput, SdkError<ListDataCatalogsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListDataCatalogsOutput, SdkError<ListDataCatalogsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListDataCatalogsOutput, ListDataCatalogsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListDataCatalogsOutput, ListDataCatalogsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListDataCatalogsPaginator
pub fn into_paginator(self) -> ListDataCatalogsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
Specifies the maximum number of data catalogs to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
Specifies the maximum number of data catalogs to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
Specifies the maximum number of data catalogs to return.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The name of the workgroup. Required if making an IAM Identity Center request.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The name of the workgroup. Required if making an IAM Identity Center request.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The name of the workgroup. Required if making an IAM Identity Center request.