#[non_exhaustive]pub struct ListDataCatalogsOutputBuilder { /* private fields */ }Expand description
A builder for ListDataCatalogsOutput.
Implementations
Sourceimpl ListDataCatalogsOutputBuilder
impl ListDataCatalogsOutputBuilder
Sourcepub fn data_catalogs_summary(self, input: DataCatalogSummary) -> Self
pub fn data_catalogs_summary(self, input: DataCatalogSummary) -> Self
Appends an item to data_catalogs_summary.
To override the contents of this collection use set_data_catalogs_summary.
A summary list of data catalogs.
Sourcepub fn set_data_catalogs_summary(
self,
input: Option<Vec<DataCatalogSummary>>,
) -> Self
pub fn set_data_catalogs_summary( self, input: Option<Vec<DataCatalogSummary>>, ) -> Self
A summary list of data catalogs.
Sourcepub fn get_data_catalogs_summary(&self) -> &Option<Vec<DataCatalogSummary>>
pub fn get_data_catalogs_summary(&self) -> &Option<Vec<DataCatalogSummary>>
A summary list of data catalogs.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn build(self) -> ListDataCatalogsOutput
pub fn build(self) -> ListDataCatalogsOutput
Consumes the builder and constructs a ListDataCatalogsOutput.